//
//  DMStepController.h
//  DevMateActivation
//
//  Created by Dmytro Tretiakov on 12/24/12.
//  Copyright (c) 2012 MacPaw Inc. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <DevMateActivation/DMActivationController.h>

//! Controller for concrete activation step
//  All defined IBOutlet properties can be used to change its' properties (visibility/target/action/...)
@interface DMStepController : NSViewController
{
@private
    __unsafe_unretained NSImageView *applicationIconView;
    __unsafe_unretained NSTextField *applicationNameField;
    __unsafe_unretained DMActivationController *activationController;
}

//! Should be overriden in subclass for correct creating of default controller
+ (NSString *)defaultNibName;

//! Creates step controller with defaultNibName file
+ (id)defaultViewController;

@property (nonatomic, unsafe_unretained) DMActivationController *activationController;

//! Will be called from activation controller before removing step view from container view
- (void)saveCurrentState:(NSMutableDictionary *)saveContainer;

//! Will be called from activation controller after moving step view into container view
//  saveContainer will have all saves states before for one activation session (from starting activation to ending it)
- (void)restoreState:(NSDictionary *)saveContainer;

//! Will be called from activation controller at start of new activation session
- (void)resetStateToDefault;

//! IB items
@property (nonatomic, assign) IBOutlet NSImageView *applicationIconView;
@property (nonatomic, assign) IBOutlet NSTextField *applicationNameField;

@end

//! Keys for storing states
FOUNDATION_EXTERN NSString *const DMActivationNumberKey; // NSString value
FOUNDATION_EXTERN NSString *const DMActivationErrorKey; // NSError value